@@ -112,9 +112,11 @@ void SimManager::initialize()
     	throw ModelicaSimulationError(SIMMANAGER,"Could not get step-event system.");
     }
 
+    _tStart = _config->getGlobalSettings()->getStartTime();
+    _tEnd = _config->getGlobalSettings()->getEndTime();
+
     LOGGER_WRITE("SimManager: Start initialization",LC_INIT,LL_DEBUG);
-    // Set flag for endless simulation (if solver returns)
-    _continueSimulation = true;
+    LOGGER_STATUS_STARTING(_tStart, _tEnd);
 
     // Reset debug ID
     _dbgId = 0;
@@ -126,8 +128,11 @@ void SimManager::initialize()
     }
     catch (std::exception& ex)
     {
+        LOGGER_WRITE("SimManager: Could not initialize system", LC_INIT, LL_ERROR);
+        LOGGER_WRITE("SimManager: " + string(ex.what()), LC_INIT, LL_ERROR);
         //ex << error_id(SIMMANAGER);
-    	throw ModelicaSimulationError(SIMMANAGER,"Could not initialize system.",string(ex.what()),false);
+        throw ModelicaSimulationError(SIMMANAGER, "Could not initialize system",
+                                      string(ex.what()), LOGGER_IS_SET(LC_INIT, LL_ERROR));
     }
 
     if (_timeevent_system)
@@ -149,8 +154,9 @@ void SimManager::initialize()
     else
         _dimtimeevent = 0;
 
-    _tStart = _config->getGlobalSettings()->getStartTime();
-    _tEnd = _config->getGlobalSettings()->getEndTime();
+    // Set flag for endless simulation (if solver returns)
+    _continueSimulation = _tEnd > _tStart;
+
     // _solver->setTimeOut(_config->getGlobalSettings()->getAlarmTime());
     _dimZeroFunc = _event_system->getDimZeroFunc();
     _solverTask = ISolver::SOLVERCALL(ISolver::FIRST_CALL);
@@ -264,24 +270,25 @@ void SimManager::runSimulation()
     #endif
     try
     {
-        LOGGER_WRITE("SimManager: Start simulation at t = " + to_string(_tStart), LC_SOLV, LL_INFO);
+        LOGGER_WRITE("SimManager: Start simulation at t = " + to_string(_tStart), LC_SOLVER, LL_INFO);
         runSingleProcess();
         // Measure time; Output SimInfos
         ISolver::SOLVERSTATUS status = _solver->getSolverStatus();
         if ((status & ISolver::DONE) || (status & ISolver::USER_STOP))
         {
-            //LOGGER_WRITE("SimManager: Simulation done at t = " + to_string(_tEnd), LC_SOLV, LL_INFO);
+            //LOGGER_WRITE("SimManager: Simulation done at t = " + to_string(_tEnd), LC_SOLVER, LL_INFO);
             writeProperties();
         }
     }
     catch (std::exception & ex)
     {
-        LOGGER_WRITE("SimManager: Simulation finish with errors at t = " + to_string(_tEnd), LC_SOLV, LL_ERROR);
+        LOGGER_WRITE("SimManager: Simulation stopped with errors before t = " +
+                     to_string(_tEnd), LC_SOLVER, LL_ERROR);
+        LOGGER_WRITE("SimManager: " + string(ex.what()), LC_SOLVER, LL_ERROR);
         writeProperties();
-
-        LOGGER_WRITE("SimManager: Error = " + string(ex.what()), LC_SOLV, LL_ERROR);
-        //ex << error_id(SIMMANAGER);
-        throw;
+        // rethrow with suppress depending on logger setting to not appear twice
+        throw ModelicaSimulationError(SIMMANAGER, "Simulation stopped with errors before t = " + to_string(_tEnd),
+                                      string(ex.what()), LOGGER_IS_SET(LC_SOLVER, LL_ERROR));
     }
     #ifdef RUNTIME_PROFILING
     if (MeasureTime::getInstance() != NULL)
@@ -299,15 +306,15 @@ void SimManager::stopSimulation()
 
 void SimManager::writeProperties()
 {
-	// declaration for Logging
-	std::pair<LogCategory, LogLevel> logM = Logger::getLogMode(LC_SOLV, LL_INFO);
+  // declaration for Logging
+  std::pair<LogCategory, LogLevel> logM = Logger::getLogMode(LC_SOLVER, LL_INFO);
 
-	LOGGER_WRITE_TUPLE("SimManager: Computation time", logM);
-	LOGGER_WRITE_TUPLE("SimManager: Simulation end time:          " + to_string(_tEnd), logM);
-    //LOGGER_WRITE("Rechenzeit in Sekunden:                 " + to_string>(_tClockEnd-_tClockStart), logM);
+  LOGGER_WRITE_TUPLE("SimManager: Simulation stop time: " + to_string(_tEnd), logM);
+  //LOGGER_WRITE("Rechenzeit in Sekunden:                 " + to_string>(_tClockEnd-_tClockStart), logM);
 
-	LOGGER_WRITE_TUPLE("Simulation info from solver:", logM);
+  LOGGER_WRITE_BEGIN("Simulation info from solver:", LC_SOLVER, LL_INFO);
   _solver->writeSimulationInfo();
+  LOGGER_WRITE_END(LC_SOLVER, LL_INFO);
 /*
      // Zeit
     if(_settings->_globalSettings->bEndlessSim)
@@ -440,12 +447,19 @@ void SimManager::writeProperties()
      */
 }
 
+/**
+    Computes all stops for the time events before starting the simulation
+
+    @param A vector of all time event stop times.
+*/
 void SimManager::computeEndTimes(std::vector<std::pair<double, int> > &tStopsSub)
 {
-    int counterTimes = 0, counterEvents = 0;
-    time_event_type timeEventPairs;                        ///< - Beinhaltet Frequenzen und Startzeit der Time-Events
+	int counterTimes = 0;
+    int counterEvents = 0;
+    time_event_type timeEventPairs;// <startTime, intervalLength> of the time events
     _writeFinalState = true;
 
+    //calculate time event stops till stopTime
     if (tStopsSub.size() == 0)
     {
         _timeevent_system->getTimeEvent(timeEventPairs);
@@ -462,7 +476,8 @@ void SimManager::computeEndTimes(std::vector<std::pair<double, int> > &tStopsSub
                     counterTimes++;
                     _solverTask = ISolver::SOLVERCALL(_solverTask | ISolver::RECALL);
                 }
-                while (iter->first + counterTimes * (iter->second) <= _tEnd)
+                //compute time event times for the whole simulation including the end time
+                while (iter->first + counterTimes * (iter->second) <= _tEnd+UROUND)
                 {
                     tStopsSub.push_back(std::make_pair(iter->first + counterTimes * (iter->second), counterEvents));
                     counterTimes++;
@@ -545,16 +560,18 @@ void SimManager::runSingleProcess()
     std::vector<std::pair<double, int> > tStopsSub;
 
     _H = _tEnd;
-    _solverTask = ISolver::SOLVERCALL(_solverTask | ISolver::RECORDCALL);
+    //nw _solverTask = ISolver::SOLVERCALL(_solverTask | ISolver::RECORDCALL);
     _solver->setStartTime(_tStart);
     _solver->setEndTime(_tEnd);
 
-    _solver->solve(_solverTask);
+    //nw _solver->solve(_solverTask);
     //initialize();
-    _solverTask = ISolver::SOLVERCALL(_solverTask ^ ISolver::RECORDCALL);
-    /* Logs temporarily disabled
+    //nw _solverTask = ISolver::SOLVERCALL(_solverTask ^ ISolver::RECORDCALL);
+
+
+	/* Logs temporarily disabled
      BOOST_LOG_SEV(simmgr_lg::get(), simmgr_normal) <<"Run single process." ; */
-    LOGGER_WRITE("SimManager: Run single process",LC_SOLV,LL_DEBUG);
+    LOGGER_WRITE("SimManager: Run single process", LC_SOLVER, LL_DEBUG);
 
     memset(_timeEventCounter, 0, _dimtimeevent * sizeof(int));
     computeEndTimes(tStopsSub);
@@ -579,13 +596,20 @@ void SimManager::runSingleProcess()
         _timeevent_system->handleTimeEvent(_timeEventCounter);
     }
 
+    _solverTask = ISolver::SOLVERCALL(_solverTask | ISolver::RECORDCALL);
+    _solver->setStartTime(_tStart);
+    _solver->setEndTime(_tEnd);
+    _solver->solve(_solverTask);
+    _solverTask = ISolver::SOLVERCALL(_solverTask ^ ISolver::RECORDCALL);
+
+
     std::vector<std::pair<double, int> >::iterator iter;
     iter = _tStops[0].begin();
     /* time measurement temporary disabled
      // Startzeit messen
      _tClockStart = Time::Time().getSeconds();
      */
-    startTime = _tStart;
+    startTime = endTime = _tStart;
     bool user_stop = false;
 
     while (_continueSimulation)
@@ -700,6 +724,8 @@ void SimManager::runSingleProcess()
     _step_event_system->setTerminal(true);
     _cont_system->evaluateAll(IContinuous::CONTINUOUS); //Is this really necessary? The solver should have already calculated the "final time point"
 
+    LOGGER_STATUS("Finished", endTime, 0.0);
+
     if (zeroVal_new)
         delete[] zeroVal_new;
 
