@@ -29,19 +29,23 @@
  *
  */
 /*
- *
  * @author Adeel Asghar <adeel.asghar@liu.se>
- *
- *
  */
 
 #include <limits>
 
 #include "ShapePropertiesDialog.h"
-#include "Commands.h"
+#include "MainWindow.h"
+#include "Options/OptionsDialog.h"
+#include "Options/NotificationsDialog.h"
+#include "Modeling/Commands.h"
 
-ShapePropertiesDialog::ShapePropertiesDialog(ShapeAnnotation *pShapeAnnotation, MainWindow *pMainWindow)
-  : QDialog(pMainWindow, Qt::WindowTitleHint)
+#include <QHeaderView>
+#include <QColorDialog>
+#include <QMessageBox>
+
+ShapePropertiesDialog::ShapePropertiesDialog(ShapeAnnotation *pShapeAnnotation, QWidget *pParent)
+  : QDialog(pParent)
 {
   mpShapeAnnotation = pShapeAnnotation;
   mOldAnnotation = "";
@@ -51,18 +55,13 @@ ShapePropertiesDialog::ShapePropertiesDialog(ShapeAnnotation *pShapeAnnotation,
   mpEllipseAnnotation = dynamic_cast<EllipseAnnotation*>(mpShapeAnnotation);
   mpTextAnnotation = dynamic_cast<TextAnnotation*>(mpShapeAnnotation);
   mpBitmapAnnotation = dynamic_cast<BitmapAnnotation*>(mpShapeAnnotation);
-  mpMainWindow = pMainWindow;
   QString title = getTitle();
   setWindowTitle(QString(Helper::applicationName).append(" - ").append(title).append(" ").append(Helper::properties));
   setAttribute(Qt::WA_DeleteOnClose);
   // heading label
-  mpShapePropertiesHeading = new Label(QString(title).append(" ").append(Helper::properties));
-  mpShapePropertiesHeading->setFont(QFont(Helper::systemFontInfo.family(), Helper::headingFontSize));
-  mpShapePropertiesHeading->setAlignment(Qt::AlignTop);
+  mpShapePropertiesHeading = Utilities::getHeadingLabel(QString(title).append(" ").append(Helper::properties));
   // set separator line
-  mHorizontalLine = new QFrame();
-  mHorizontalLine->setFrameShape(QFrame::HLine);
-  mHorizontalLine->setFrameShadow(QFrame::Sunken);
+  mHorizontalLine = Utilities::getHeadingLine();
   // Transformations Group Box
   mpTransformationGroupBox = new QGroupBox(tr("Transformation"));
   mpOriginXLabel = new Label(Helper::originX);
@@ -336,7 +335,7 @@ ShapePropertiesDialog::ShapePropertiesDialog(ShapeAnnotation *pShapeAnnotation,
   mpFillStyleGroupBox->setLayout(pFillStyleGroupBoxLayout);
   // Image Group Box
   mpImageGroupBox = new QGroupBox(tr("Image"));
-  mpFileLabel = new Label(Helper::file);
+  mpFileLabel = new Label(Helper::fileLabel);
   mpFileTextBox = new QLineEdit(mpShapeAnnotation->getFileName());
   mpFileTextBox->setEnabled(false);
   mpBrowseFileButton = new QPushButton(Helper::browse);
@@ -371,6 +370,7 @@ ShapePropertiesDialog::ShapePropertiesDialog(ShapeAnnotation *pShapeAnnotation,
 #else /* Qt4 */
   mpPointsTableWidget->horizontalHeader()->setResizeMode(QHeaderView::Stretch);
 #endif
+  mpPointsTableWidget->horizontalHeader()->setDefaultAlignment(Qt::AlignLeft);
   QStringList headerLabels;
   headerLabels << "X" << "Y";
   mpPointsTableWidget->setHorizontalHeaderLabels(headerLabels);
@@ -690,6 +690,8 @@ void ShapePropertiesDialog::saveShapeProperties()
 
 bool ShapePropertiesDialog::applyShapeProperties()
 {
+  // we need to set focus on the OK button otherwise QTableWidget doesn't read any active cell editing value.
+  mpOkButton->setFocus(Qt::ActiveWindowFocusReason);
   // save the old annotation before applying anything.
   mOldAnnotation = mpShapeAnnotation->getOMCShapeAnnotation();
   /* validate points */
@@ -698,7 +700,7 @@ bool ShapePropertiesDialog::applyShapeProperties()
     bool Ok;
     pTableWidgetItem->text().toFloat(&Ok);
     if (!Ok || pTableWidgetItem->text().isEmpty()) {
-      QMessageBox::critical(mpMainWindow, QString(Helper::applicationName).append(" - ").append(Helper::error),
+      QMessageBox::critical(MainWindow::instance(), QString(Helper::applicationName).append(" - ").append(Helper::error),
                             GUIMessages::getMessage(GUIMessages::ENTER_VALID_NUMBER)
                             .arg("points item ("+  QString::number(i+1) +",0)"), Helper::ok);
       mpPointsTableWidget->editItem(pTableWidgetItem);
@@ -707,7 +709,7 @@ bool ShapePropertiesDialog::applyShapeProperties()
     pTableWidgetItem = mpPointsTableWidget->item(i, 1); /* point Y value */
     pTableWidgetItem->text().toFloat(&Ok);
     if (!Ok || pTableWidgetItem->text().isEmpty()) {
-      QMessageBox::critical(mpMainWindow, QString(Helper::applicationName).append(" - ").append(Helper::error),
+      QMessageBox::critical(MainWindow::instance(), QString(Helper::applicationName).append(" - ").append(Helper::error),
                             GUIMessages::getMessage(GUIMessages::ENTER_VALID_NUMBER)
                             .arg("points table ["+  QString::number(i+1) +",1]"), Helper::ok);
       mpPointsTableWidget->editItem(pTableWidgetItem);
@@ -718,15 +720,15 @@ bool ShapePropertiesDialog::applyShapeProperties()
   if (mpBitmapAnnotation) {
     if (mpStoreImageInModelCheckBox->isChecked() && mpShapeAnnotation->getImageSource().isEmpty()) {
       if (mpFileTextBox->text().isEmpty()) {
-        QMessageBox::critical(mpMainWindow, QString(Helper::applicationName).append(" - ").append(Helper::error),
-                              GUIMessages::getMessage(GUIMessages::ENTER_NAME).arg(Helper::file), Helper::ok);
+        QMessageBox::critical(MainWindow::instance(), QString(Helper::applicationName).append(" - ").append(Helper::error),
+                              GUIMessages::getMessage(GUIMessages::ENTER_NAME).arg(Helper::fileLabel), Helper::ok);
         mpFileTextBox->setFocus();
         return false;
       }
     } else if (!mpStoreImageInModelCheckBox->isChecked()) {
       if (mpFileTextBox->text().isEmpty()) {
-        QMessageBox::critical(mpMainWindow, QString(Helper::applicationName).append(" - ").append(Helper::error),
-                              GUIMessages::getMessage(GUIMessages::ENTER_NAME).arg(Helper::file), Helper::ok);
+        QMessageBox::critical(MainWindow::instance(), QString(Helper::applicationName).append(" - ").append(Helper::error),
+                              GUIMessages::getMessage(GUIMessages::ENTER_NAME).arg(Helper::fileLabel), Helper::ok);
         mpFileTextBox->setFocus();
         return false;
       }
@@ -790,7 +792,7 @@ bool ShapePropertiesDialog::applyShapeProperties()
         QUrl fileUrl(mpFileTextBox->text());
         QFileInfo fileInfo(mpFileTextBox->text());
         QFileInfo classFileInfo(mpShapeAnnotation->getGraphicsView()->getModelWidget()->getLibraryTreeItem()->getFileName());
-        MainWindow *pMainWindow = mpShapeAnnotation->getGraphicsView()->getModelWidget()->getModelWidgetContainer()->getMainWindow();
+        MainWindow *pMainWindow = MainWindow::instance();
         /* if its a modelica:// link then make it absolute path */
         QString fileName;
         if (fileUrl.scheme().toLower().compare("modelica") == 0) {
@@ -810,7 +812,7 @@ bool ShapePropertiesDialog::applyShapeProperties()
       mpShapeAnnotation->setImage(mpPreviewImageLabel->pixmap()->toImage());
     } else {
       /* find the class to create a relative path */
-      MainWindow *pMainWindow = mpShapeAnnotation->getGraphicsView()->getModelWidget()->getModelWidgetContainer()->getMainWindow();
+      MainWindow *pMainWindow = MainWindow::instance();
       LibraryTreeItem *pLibraryTreeItem = mpShapeAnnotation->getGraphicsView()->getModelWidget()->getLibraryTreeItem();
       QString nameStructure = StringHandler::getFirstWordBeforeDot(pLibraryTreeItem->getNameStructure());
       pLibraryTreeItem = pMainWindow->getLibraryWidget()->getLibraryTreeModel()->findLibraryTreeItem(nameStructure);
@@ -818,8 +820,7 @@ bool ShapePropertiesDialog::applyShapeProperties()
       QFileInfo classFileInfo(pLibraryTreeItem->getFileName());
       QDir classDirectory = classFileInfo.absoluteDir();
       QString relativeImagePath = classDirectory.relativeFilePath(mpFileTextBox->text());
-      mpShapeAnnotation->setFileName(QString("modelica://").append(pLibraryTreeItem->getNameStructure()).append("/")
-                                     .append(relativeImagePath));
+      mpShapeAnnotation->setFileName(QString("modelica://").append(pLibraryTreeItem->getNameStructure()).append("/").append(relativeImagePath));
       mpShapeAnnotation->setImageSource("");
       mpShapeAnnotation->setImage(mpPreviewImageLabel->pixmap()->toImage());
     }
@@ -836,14 +837,14 @@ bool ShapePropertiesDialog::applyShapeProperties()
     UpdateConnectionCommand *pUpdateConnectionCommand;
     pUpdateConnectionCommand = new UpdateConnectionCommand(mpLineAnnotation, mOldAnnotation, mpShapeAnnotation->getOMCShapeAnnotation());
     mpShapeAnnotation->getGraphicsView()->getModelWidget()->getUndoStack()->push(pUpdateConnectionCommand);
-    mpShapeAnnotation->getGraphicsView()->getModelWidget()->updateModelicaText();
+    mpShapeAnnotation->getGraphicsView()->getModelWidget()->updateModelText();
   } else {
     // create a UpdateShapeCommand object and push it to the undo stack.
     UpdateShapeCommand *pUpdateShapeCommand;
     pUpdateShapeCommand = new UpdateShapeCommand(mpShapeAnnotation, mOldAnnotation, mpShapeAnnotation->getOMCShapeAnnotation());
     mpShapeAnnotation->getGraphicsView()->getModelWidget()->getUndoStack()->push(pUpdateShapeCommand);
     mpShapeAnnotation->getGraphicsView()->getModelWidget()->updateClassAnnotationIfNeeded();
-    mpShapeAnnotation->getGraphicsView()->getModelWidget()->updateModelicaText();
+    mpShapeAnnotation->getGraphicsView()->getModelWidget()->updateModelText();
   }
   return true;
 }
@@ -867,9 +868,9 @@ void ShapePropertiesDialog::storeImageInModelToggled(bool checked)
    * If the model is not saved then make the check box checked again.
    */
   if (!checked) {
-    MainWindow *pMainWindow = mpBitmapAnnotation->getGraphicsView()->getModelWidget()->getModelWidgetContainer()->getMainWindow();
+    MainWindow *pMainWindow = MainWindow::instance();
     if (!mpBitmapAnnotation->getGraphicsView()->getModelWidget()->getLibraryTreeItem()->isFilePathValid()) {
-      if (pMainWindow->getOptionsDialog()->getNotificationsPage()->getSaveModelForBitmapInsertionCheckBox()->isChecked()) {
+      if (OptionsDialog::instance()->getNotificationsPage()->getSaveModelForBitmapInsertionCheckBox()->isChecked()) {
         NotificationsDialog *pNotificationsDialog = new NotificationsDialog(NotificationsDialog::SaveModelForBitmapInsertion,
                                                                             NotificationsDialog::InformationIcon,
                                                                             pMainWindow);
