@@ -29,14 +29,11 @@
  *
  */
 /*
- *
  * @author Adeel Asghar <adeel.asghar@liu.se>
- *
- *
  */
 
 #include "TextAnnotation.h"
-#include "Commands.h"
+#include "Modeling/Commands.h"
 
 /*!
  * \class TextAnnotation
@@ -66,6 +63,7 @@ TextAnnotation::TextAnnotation(ShapeAnnotation *pShapeAnnotation, Component *pPa
   : ShapeAnnotation(pParent), mpComponent(pParent)
 {
   updateShape(pShapeAnnotation);
+  initUpdateVisible(); // DynamicSelect for visible attribute
   initUpdateTextString();
   setPos(mOrigin);
   setRotation(mRotation);
@@ -95,6 +93,9 @@ TextAnnotation::TextAnnotation(Component *pParent)
   GraphicItem::setDefaults();
   FilledShape::setDefaults();
   ShapeAnnotation::setDefaults();
+  // give a reasonable size to default component text
+  mExtents.replace(0, QPointF(-50, -50));
+  mExtents.replace(1, QPointF(50, 50));
   setTextString("%name");
   initUpdateTextString();
   setPos(mOrigin);
@@ -123,7 +124,19 @@ void TextAnnotation::parseShapeAnnotation(QString annotation)
       mExtents.replace(i, QPointF(extentPoints.at(0).toFloat(), extentPoints.at(1).toFloat()));
   }
   // 10th item of the list contains the textString.
-  mOriginalTextString = StringHandler::removeFirstLastQuotes(list.at(9));
+  if (list.at(9).startsWith("{")) {
+    // DynamicSelect
+    QStringList args = StringHandler::getStrings(StringHandler::removeFirstLastCurlBrackets(list.at(9)));
+    if (args.count() > 0)
+      mOriginalTextString = StringHandler::removeFirstLastQuotes(args.at(0));
+    if (args.count() > 1)
+      mDynamicTextString << args.at(1);  // variable name
+    if (args.count() > 2)
+      mDynamicTextString << args.at(2);  // significantDigits
+  }
+  else {
+    mOriginalTextString = StringHandler::removeFirstLastQuotes(list.at(9));
+  }
   mTextString = mOriginalTextString;
   initUpdateTextString();
   // 11th item of the list contains the fontSize.
@@ -208,7 +221,7 @@ void TextAnnotation::paint(QPainter *painter, const QStyleOptionGraphicsItem *op
   } else if (mpComponent && mpComponent->getGraphicsView()->isRenderingLibraryPixmap()) {
     return;
   }
-  if (mVisible) {
+  if (mVisible || !mDynamicVisible.isEmpty()) {
     drawTextAnnotaion(painter);
   }
 }
@@ -223,9 +236,11 @@ void TextAnnotation::drawTextAnnotaion(QPainter *painter)
   applyLinePattern(painter);
   /* Don't apply the fill patterns on Text shapes. */
   /*applyFillPattern(painter);*/
+  qreal dx = ((-boundingRect().left()) - boundingRect().right());
+  qreal dy = ((-boundingRect().top()) - boundingRect().bottom());
   // first we invert the painter since we have our coordinate system inverted.
   painter->scale(1.0, -1.0);
-  painter->translate(0, ((-boundingRect().top()) - boundingRect().bottom()));
+  painter->translate(0, dy);
   mTextString = StringHandler::removeFirstLastQuotes(mTextString);
   mTextString = StringHandler::unparse(QString("\"").append(mTextString).append("\""));
   QFont font;
@@ -264,20 +279,36 @@ void TextAnnotation::drawTextAnnotaion(QPainter *painter)
     if (pComponent && pComponent->mTransformation.isValid()) {
       QPointF extent1 = pComponent->mTransformation.getExtent1();
       QPointF extent2 = pComponent->mTransformation.getExtent2();
-      qreal dy = ((-boundingRect().top()) - boundingRect().bottom());
-      // if horizontal flip
-      if (extent2.x() < extent1.x()) {
-        painter->scale(-1.0, 1.0);
-      }
-      // if vertical flip
-      if (extent2.y() < extent1.y()) {
-        painter->scale(1.0, -1.0);
-        painter->translate(0, dy);
-      }
-      qreal angle = StringHandler::getNormalizedAngle(pComponent->mTransformation.getRotateAngle());
-      if (angle == 180) {
-        painter->scale(-1.0, -1.0);
-        painter->translate(0, dy);
+      qreal componentAngle = StringHandler::getNormalizedAngle(pComponent->mTransformation.getRotateAngle());
+      qreal shapeAngle = StringHandler::getNormalizedAngle(getRotation());
+      // if shape has its own angle
+      if (shapeAngle > 0) {
+        shapeAngle = StringHandler::getNormalizedAngle(pComponent->mTransformation.getRotateAngle() + getRotation());
+        if (shapeAngle == 180) {
+          painter->scale(-1.0, -1.0);
+          painter->translate(dx, dy);
+        }
+        if (extent2.x() < extent1.x()) {  // if vertical flip
+          painter->scale(1.0, -1.0);
+          painter->translate(0, dy);
+        }
+        if (extent2.y() < extent1.y()) {  // if horizontal flip
+          painter->scale(-1.0, 1.0);
+          painter->translate(dx, 0);
+        }
+      } else {
+        if (componentAngle == 180) {
+          painter->scale(-1.0, -1.0);
+          painter->translate(dx, dy);
+        }
+        if (extent2.x() < extent1.x()) {  // if horizontal flip
+          painter->scale(-1.0, 1.0);
+          painter->translate(dx, 0);
+        }
+        if (extent2.y() < extent1.y()) {  // if vertical flip
+          painter->scale(1.0, -1.0);
+          painter->translate(0, dy);
+        }
       }
     }
   } else {
@@ -402,7 +433,7 @@ void TextAnnotation::updateShape(ShapeAnnotation *pShapeAnnotation)
 void TextAnnotation::initUpdateTextString()
 {
   if (mpComponent) {
-    if (mOriginalTextString.contains("%")) {
+    if (mOriginalTextString.contains("%") || mDynamicTextString.count() > 0) {
       updateTextString();
       connect(mpComponent, SIGNAL(displayTextChanged()), SLOT(updateTextString()), Qt::UniqueConnection);
     }
@@ -442,6 +473,24 @@ void TextAnnotation::updateTextStringHelper(QRegExp regExp)
  */
 void TextAnnotation::updateTextString()
 {
+  /* optional DynamicSelect of textString attribute */
+  QVariant dynamicValue; // isNull() per default
+  if (mDynamicTextString.count() > 0) {
+    dynamicValue = getDynamicValue(mDynamicTextString.at(0).toString());
+  }
+  if (!dynamicValue.isNull()) {
+    mTextString = dynamicValue.toString();
+    if (mTextString.isEmpty()) {
+      /* use variable name as default value if result not found */
+      mTextString = mDynamicTextString.at(0).toString();
+    }
+    else if (mDynamicTextString.count() > 1) {
+      int digits = mDynamicTextString.at(1).toInt();
+      mTextString = QString::number(mTextString.toDouble(), 'g', digits);
+    }
+    return;
+  }
+  /* alternatively use model provided value */
   /* From Modelica Spec 32revision2,
    * There are a number of common macros that can be used in the text, and they should be replaced when displaying
    * the text as follows:
