@@ -29,10 +29,7 @@
  *
  */
 /*
- *
  * @author Adeel Asghar <adeel.asghar@liu.se>
- *
- *
  */
 
 #include "Helper.h"
@@ -55,7 +52,7 @@ QString Helper::imageFileTypes = "SVG (*.svg);;PNG image (*.png);;Windows BMP im
 QString Helper::bitmapFileTypes = "PNG image (*.png);Windows BMP image (*.bmp);JPEG (*.jpg *.jpeg)";
 QString Helper::fmuFileTypes = "FMU Files (*.fmu)";
 QString Helper::xmlFileTypes = "XML Files (*.xml)";
-QString Helper::infoXmlFileTypes = "OM Info Files (*_info.xml *_info.json)";
+QString Helper::infoXmlFileTypes = "OM Info Files (*_info.json)";
 QString Helper::matFileTypes = "MAT Files (*.mat)";
 QString Helper::omResultFileTypes = "OpenModelica Result Files (*.mat *.plt *.csv)";
 #ifdef WIN32
@@ -65,9 +62,9 @@ QString Helper::exeFileTypes = "Executable files (*)";
 #endif
 QString Helper::txtFileTypes = "TXT Files (*.txt)";
 QString Helper::figaroFileTypes = "Figaro Files (*.fi)";
+QString Helper::visualizationFileTypes = "Visualization Files (*.mat *.csv *.fmu);;Visualization MAT(*.mat);;Visualization CSV(*.csv);;Visualization FMU(*.fmu)";
 int Helper::treeIndentation = 13;
 QSize Helper::iconSize = QSize(20, 20);
-QSize Helper::buttonIconSize = QSize(16, 16);
 int Helper::tabWidth = 20;
 QString Helper::modelicaComponentFormat = "image/modelica-component";
 QString Helper::modelicaFileFormat = "text/uri-list";
@@ -91,8 +88,11 @@ QString Helper::textOutput = "Text";
 QString Helper::utf8 = "UTF-8";
 QFontInfo Helper::systemFontInfo = QFontInfo(QFont());
 QFontInfo Helper::monospacedFontInfo = QFontInfo(QFont());
+#ifdef Q_OS_MAC
+QString Helper::toolsOptionsPath = "OMEdit->Preferences";
+#else
 QString Helper::toolsOptionsPath = "Tools->Options";
-QString Helper::toolsOptionsPathMAC = "OMEdit->Preferences";
+#endif
 /* Meta Modelica Types */
 QString Helper::MODELICA_METATYPE = QString("modelica_metatype");
 QString Helper::MODELICA_STRING = QString("modelica_string");
@@ -119,10 +119,13 @@ QString Helper::openConvertModelicaFiles;
 QString Helper::libraries;
 QString Helper::clearRecentFiles;
 QString Helper::encoding;
+QString Helper::fileLabel;
 QString Helper::file;
+QString Helper::folder;
 QString Helper::browse;
 QString Helper::ok;
 QString Helper::cancel;
+QString Helper::reset;
 QString Helper::close;
 QString Helper::error;
 QString Helper::chooseFile;
@@ -148,6 +151,7 @@ QString Helper::path;
 QString Helper::type;
 QString Helper::information;
 QString Helper::rename;
+QString Helper::renameTip;
 QString Helper::checkModel;
 QString Helper::checkModelTip;
 QString Helper::checkAllModels;
@@ -182,7 +186,7 @@ QString Helper::unloadClass;
 QString Helper::duplicate;
 QString Helper::duplicateTip;
 QString Helper::unloadClassTip;
-QString Helper::unloadTLMOrTextTip;
+QString Helper::unloadMetaModelOrTextTip;
 QString Helper::refresh;
 QString Helper::simulate;
 QString Helper::simulateTip;
@@ -190,10 +194,13 @@ QString Helper::reSimulate;
 QString Helper::reSimulateTip;
 QString Helper::reSimulateSetup;
 QString Helper::reSimulateSetupTip;
+QString Helper::exportVariables;
 QString Helper::simulateWithTransformationalDebugger;
 QString Helper::simulateWithTransformationalDebuggerTip;
 QString Helper::simulateWithAlgorithmicDebugger;
 QString Helper::simulateWithAlgorithmicDebuggerTip;
+QString Helper::simulateWithAnimation;
+QString Helper::simulateWithAnimationTip;
 QString Helper::simulationSetup;
 QString Helper::simulationSetupTip;
 QString Helper::simulation;
@@ -221,7 +228,7 @@ QString Helper::arrowSize;
 QString Helper::size;
 QString Helper::lineStyle;
 QString Helper::color;
-QString Helper::fontAndColors;
+QString Helper::Colors;
 QString Helper::fontFamily;
 QString Helper::fontSize;
 QString Helper::pickColor;
@@ -246,13 +253,14 @@ QString Helper::iconView;
 QString Helper::diagramView;
 QString Helper::textView;
 QString Helper::documentationView;
-QString Helper::searchClasses;
+QString Helper::filterClasses;
 QString Helper::findReplaceModelicaText;
 QString Helper::left;
 QString Helper::center;
 QString Helper::right;
 QString Helper::createConnection;
-QString Helper::findVariables;
+QString Helper::connectionAttributes;
+QString Helper::filterVariables;
 QString Helper::openClass;
 QString Helper::openClassTip;
 QString Helper::viewDocumentation;
@@ -275,6 +283,7 @@ QString Helper::executionFraction;
 QString Helper::debuggingFileNotSaveInfo;
 QString Helper::algorithmicDebugger;
 QString Helper::debugConfigurations;
+QString Helper::debugConfigurationsTip;
 QString Helper::resume;
 QString Helper::interrupt;
 QString Helper::exit;
@@ -282,6 +291,7 @@ QString Helper::stepOver;
 QString Helper::stepInto;
 QString Helper::stepReturn;
 QString Helper::attachToRunningProcess;
+QString Helper::attachToRunningProcessTip;
 QString Helper::crashReport;
 QString Helper::parsingFailedJson;
 QString Helper::expandAll;
@@ -292,11 +302,34 @@ QString Helper::simulationOutput;
 QString Helper::cancelSimulation;
 QString Helper::fetchInterfaceData;
 QString Helper::fetchInterfaceDataTip;
+QString Helper::alignInterfaces;
+QString Helper::alignInterfacesTip;
 QString Helper::tlmCoSimulationSetup;
 QString Helper::tlmCoSimulationSetupTip;
 QString Helper::tlmCoSimulation;
+QString Helper::animationChooseFile;
+QString Helper::animationChooseFileTip;
+QString Helper::animationInitialize;
+QString Helper::animationInitializeTip;
+QString Helper::animationPlay;
+QString Helper::animationPlayTip;
+QString Helper::animationPause;
+QString Helper::animationPauseTip;
+QString Helper::simulationParams;
+QString Helper::simulationParamsTip;
 QString Helper::running;
 QString Helper::finished;
+QString Helper::newVariable;
+QString Helper::library;
+QString Helper::moveUp;
+QString Helper::moveDown;
+QString Helper::fixErrorsManually;
+QString Helper::revertToLastCorrectVersion;
+QString Helper::OMCFlags;
+QString Helper::OMCFlagsTip;
+QString Helper::saveExperimentAnnotation;
+QString Helper::saveOpenModelicaSimulationFlagsAnnotation;
+QString Helper::item;
 
 void Helper::initHelperVariables()
 {
@@ -308,10 +341,13 @@ void Helper::initHelperVariables()
   Helper::libraries = tr("Libraries");
   Helper::clearRecentFiles = tr("Clear Recent Files");
   Helper::encoding = tr("Encoding:");
-  Helper::file = tr("File:");
+  Helper::fileLabel = tr("File:");
+  Helper::file = tr("File");
+  Helper::folder = tr("Folder");
   Helper::browse = tr("Browse...");
   Helper::ok = tr("OK");
   Helper::cancel = tr("Cancel");
+  Helper::reset = tr("Reset");
   Helper::close = tr("Close");
   Helper::error = tr("Error");
   Helper::chooseFile = tr("Choose File");
@@ -337,7 +373,8 @@ void Helper::initHelperVariables()
   Helper::path = tr("Path:");
   Helper::type = tr("Type");
   Helper::information = tr("Information");
-  Helper::rename = tr("rename");
+  Helper::rename = tr("Rename");
+  Helper::renameTip = tr("Renames an item");
   Helper::checkModel = tr("Check Model");
   Helper::checkModelTip = tr("Check the Modelica class");
   Helper::checkAllModels = tr("Check All Models");
@@ -372,7 +409,7 @@ void Helper::initHelperVariables()
   Helper::duplicateTip = tr("Duplicates the item");
   Helper::unloadClass = tr("Unload");
   Helper::unloadClassTip = tr("Unload the Modelica class");
-  Helper::unloadTLMOrTextTip = tr("Unload the TLM/Text file");
+  Helper::unloadMetaModelOrTextTip = tr("Unloads the MetaModel/Text file");
   Helper::refresh = tr("Refresh");
   Helper::simulate = tr("Simulate");
   Helper::simulateTip = tr("Simulates the Modelica class");
@@ -380,10 +417,13 @@ void Helper::initHelperVariables()
   Helper::reSimulateTip = tr("Re-simulates the Modelica class");
   Helper::reSimulateSetup = tr("Re-simulate Setup");
   Helper::reSimulateSetupTip = tr("Setup re-simulation settings");
+  Helper::exportVariables = tr("Export Variables");
   Helper::simulateWithTransformationalDebugger = tr("Simulate with Transformational Debugger");
   Helper::simulateWithTransformationalDebuggerTip = tr("Simulates the Modelica class with Transformational Debugger");
   Helper::simulateWithAlgorithmicDebugger = tr("Simulate with Algorithmic Debugger");
   Helper::simulateWithAlgorithmicDebuggerTip = tr("Simulates the Modelica class with Algorithmic Debugger");
+  Helper::simulateWithAnimation = tr("Simulate with Animation");
+  Helper::simulateWithAnimationTip = tr("Simulates the Modelica class with Animation");
   Helper::simulationSetup = tr("Simulation Setup");
   Helper::simulationSetupTip = tr("Setup simulation settings");
   Helper::simulation = tr("Simulation");
@@ -411,7 +451,7 @@ void Helper::initHelperVariables()
   Helper::size = tr("Size:");
   Helper::lineStyle = tr("Line Style");
   Helper::color = tr("Color:");
-  Helper::fontAndColors = tr("Font and Colors");
+  Helper::Colors = tr("Colors");
   Helper::fontFamily = tr("Font Family:");
   Helper::fontSize = tr("Font Size:");
   Helper::pickColor = tr("Pick Color");
@@ -436,13 +476,14 @@ void Helper::initHelperVariables()
   Helper::diagramView = tr("Diagram View");
   Helper::textView = tr("Text View");
   Helper::documentationView = tr("Documentation View");
-  Helper::searchClasses = tr("Search Classes");
+  Helper::filterClasses = tr("Filter Classes");
   Helper::findReplaceModelicaText = tr("Find/Replace...");
   Helper::left = tr("Left");
   Helper::center = tr("Center");
   Helper::right = tr("Right");
   Helper::createConnection = tr("Create Connection");
-  Helper::findVariables = tr("Find Variables");
+  Helper::connectionAttributes = tr("Connection Attributes");
+  Helper::filterVariables = tr("Filter Variables");
   Helper::openClass = tr("Open Class");
   Helper::openClassTip = tr("Opens the class details");
   Helper::viewDocumentation = tr("View Documentation");
@@ -465,6 +506,7 @@ void Helper::initHelperVariables()
   Helper::debuggingFileNotSaveInfo = tr("<b>Info: </b>Update the actual model in <b>Modeling</b> perspective and simulate again. This is only shown for debugging purpose. Your changes will not be saved.");
   Helper::algorithmicDebugger = tr("Algorithmic Debugger");
   Helper::debugConfigurations = tr("Debug Configurations");
+  Helper::debugConfigurationsTip = tr("Manage debug configurations");
   Helper::resume = tr("Resume");
   Helper::interrupt = tr("Interrupt");
   Helper::exit = tr("Exit");
@@ -472,6 +514,7 @@ void Helper::initHelperVariables()
   Helper::stepInto = tr("Step Into");
   Helper::stepReturn = tr("Step Return");
   Helper::attachToRunningProcess = tr("Attach to Running Process");
+  Helper::attachToRunningProcessTip = tr("Attach the debugger to running process");
   Helper::crashReport = tr("Crash Report");
   Helper::parsingFailedJson = tr("Parsing of JSON file failed");
   Helper::expandAll = tr("Expand All");
@@ -481,12 +524,35 @@ void Helper::initHelperVariables()
   Helper::simulationOutput = tr("Simulation Output");
   Helper::cancelSimulation = tr("Cancel Simulation");
   Helper::fetchInterfaceData = tr("Fetch Interface Data");
-  Helper::fetchInterfaceDataTip = tr("Fetches the interface data for TLM co-simulation");
+  Helper::fetchInterfaceDataTip = tr("Fetches the interface data");
+  Helper::alignInterfaces = tr("Align Interfaces");
+  Helper::alignInterfacesTip = tr("Aligns the interfaces");
   Helper::tlmCoSimulationSetup = tr("TLM Co-Simulation Setup");
   Helper::tlmCoSimulationSetupTip = tr("Opens the TLM co-simulation setup");
   Helper::tlmCoSimulation = tr("TLM Co-Simulation");
+  Helper::animationChooseFile = tr("Animation File");
+  Helper::animationChooseFileTip = tr("Open an animation.");
+  Helper::animationInitialize = tr("Initialize");
+  Helper::animationInitializeTip = tr("Initialize the animation scene");
+  Helper::animationPlay = tr("Play");
+  Helper::animationPlayTip = tr("Play the animation");
+  Helper::animationPause = tr("Pause");
+  Helper::animationPauseTip = tr("Pause the animation");
+  Helper::simulationParams = tr("Simulation Parameters");
+  Helper::simulationParamsTip = tr("Shows the Simulation Parameters dialog");
   Helper::running = tr("Running");
   Helper::finished = tr("Finished");
+  Helper::newVariable = tr("<New Variable>");
+  Helper::library = tr("Library");
+  Helper::moveUp = tr("Move Up");
+  Helper::moveDown = tr("Move Down");
+  Helper::fixErrorsManually = tr("Fix error(s) manually");
+  Helper::revertToLastCorrectVersion = tr("Revert to last correct version");
+  Helper::OMCFlags = tr("OMC Flags");
+  Helper::OMCFlagsTip = tr("Space separated list of flags e.g., +d=initialization +cheapmatchingAlgorithm=3");
+  Helper::saveExperimentAnnotation = tr("Save experiment annotation inside model");
+  Helper::saveOpenModelicaSimulationFlagsAnnotation = tr("Save __OpenModelica_simulationFlags annotation inside model");
+  Helper::item = tr("item");
 }
 
 QString GUIMessages::getMessage(int type)
@@ -496,7 +562,7 @@ QString GUIMessages::getMessage(int type)
     case CHECK_MESSAGES_BROWSER:
       return tr("Please check the Messages Browser for more error specific details.");
     case SAME_COMPONENT_NAME:
-      return tr("A Component with the same name already exists. Please choose another Name.");
+      return tr("A Component with the name <b>%1</b> already exists. Please choose another name.");
     case SAME_COMPONENT_CONNECT:
       return tr("You cannot connect a component to itself.");
     case NO_MODELICA_CLASS_OPEN:
@@ -518,9 +584,9 @@ QString GUIMessages::getMessage(int type)
     case OPENMODELICAHOME_NOT_FOUND:
       return tr("Could not find environment variable OPENMODELICAHOME. Please make sure OpenModelica is installed properly.");
     case ERROR_OCCURRED:
-      return tr("Following error has occurred. \n\n%1");
-    case ERROR_IN_MODELICA_TEXT:
-      return tr("Problems are found in Modelica Text. <br />");
+      return tr("Following error has occurred.<br />%1");
+    case ERROR_IN_TEXT:
+      return tr("Problems are found in %1 Text. <br />");
     case REVERT_PREVIOUS_OR_FIX_ERRORS_MANUALLY:
       return tr("<br /><br />If you cannot find the source of the error, you can always <b>revert to the last correct version</b>.");
     case NO_OPENMODELICA_KEYWORDS:
@@ -530,7 +596,7 @@ QString GUIMessages::getMessage(int type)
     case UNABLE_TO_OPEN_FILE:
       return tr("Unable to open file <b>%1</b>.");
     case UNABLE_TO_SAVE_FILE:
-      return tr("Unable to save the file <b>%1</b>.");
+      return tr("Unable to save the file <b>%1</b>. %2");
     case FILE_NOT_FOUND:
       return tr("The file <b>%1</b> not found.");
     case ERROR_OPENING_FILE:
@@ -549,10 +615,10 @@ QString GUIMessages::getMessage(int type)
       return tr("You cannot insert <b>%1</b>, it is a <b>%2</b>. Only <b>connector</b> is allowed on the icon layer.");
     case PLOT_PARAMETRIC_DIFF_FILES:
       return tr("You cannot do a plot parametric between two different simulation result files. Make sure you select two variables from the same simulation result file.");
-    case FILE_FORMAT_NOT_SUPPORTED:
-      return tr("The file <b>%1</b> is not a valid Modelica file. The file format is not supported. You can only open <b>%2</b>.");
     case ENTER_VALID_NUMBER:
       return tr("Enter a valid number value for <b>%1</b>.");
+    case ENTER_VALUE:
+      return tr("Enter a value for <b>%1</b>.");
     case ITEM_DROPPED_ON_ITSELF:
       return tr("You cannot drop an item on itself.");
     case MAKE_REPLACEABLE_IF_PARTIAL:
@@ -569,8 +635,10 @@ QString GUIMessages::getMessage(int type)
       return tr("Are you sure you want to unload <b>%1</b>? Everything contained inside this class will also be unloaded.");
     case DELETE_CLASS_MSG:
       return tr("Are you sure you want to delete <b>%1</b>? Everything contained inside this class will also be deleted.");
-    case DELETE_TEXT_FILE_MSG:
+    case UNLOAD_TEXT_FILE_MSG:
       return tr("Are you sure you want to unload <b>%1</b>?");
+    case DELETE_TEXT_FILE_MSG:
+      return tr("Are you sure you want to delete <b>%1</b>?<br /><br />This will also delete from file system.");
     case WRONG_MODIFIER:
       return tr("The Modifier <b>%1</b> format is invalid. The correct format is <b>phi(start=1)</b>");
     case SET_INFO_XML_FLAG:
@@ -597,39 +665,16 @@ QString GUIMessages::getMessage(int type)
       return tr("TLM co-simulation session is already running. Only one session is allowed.");
     case TERMINAL_COMMAND_NOT_SET:
       return tr("Terminal command is not set. You can define a new terminal command in <b>%1->General->Terminal Command</b>.");
+    case UNABLE_FIND_COMPONENT:
+      return tr("Unable to find component %1 while parsing connection %2.");
+    case SELECT_SIMULATION_OPTION:
+      return tr("Select at least one of the following options, <br /><br />* %1<br />* %2<br />* %3")
+          .arg(Helper::saveExperimentAnnotation)
+          .arg(Helper::saveOpenModelicaSimulationFlagsAnnotation)
+          .arg(Helper::simulate);
+    case MULTIPLE_DECLARATIONS_COMPONENT:
+      return tr("Multiple declarations of component <b>%1</b> are found.");
     default:
       return "";
   }
 }
-
-QString& OpenModelica::tempDirectory()
-{
-  static int init = 0;
-  static QString tmpPath;
-  if (!init) {
-    init = 1;
-#ifdef WIN32
-    tmpPath = QDir::tempPath() + "/OpenModelica/OMEdit/";
-#else // UNIX environment
-    char *user = getenv("USER");
-    tmpPath = QDir::tempPath() + "/OpenModelica_" + QString(user ? user : "nobody") + "/OMEdit/";
-#endif
-    tmpPath.remove("\"");
-    if (!QDir().exists(tmpPath))
-      QDir().mkpath(tmpPath);
-  }
-  return tmpPath;
-}
-
-QSettings* OpenModelica::getApplicationSettings()
-{
-  static int init = 0;
-  static QSettings *pSettings;
-  if (!init) {
-    init = 1;
-    pSettings = new QSettings(QSettings::IniFormat, QSettings::UserScope, Helper::organization, Helper::application);
-    pSettings->setIniCodec(Helper::utf8.toStdString().data());
-  }
-  return pSettings;
-}
-
